@@ -31,18 +31,18 @@ class ClusterProcessor:
         cfg: Optional[Config] = None,
         config_path: Optional[str | Path] = None,
     ) -> None:
-        # 1) Cargar configuración con el loader nuevo
+       
         if cfg is None:
             config_path = Path(config_path) if config_path else Path.cwd() / "input_params.json"
-            self.cfg = Config.from_file(config_path)  # usa graph_construction→cfg.graph, paths en Path
+            self.cfg = Config.from_file(config_path) 
         else:
             self.cfg = cfg
 
-        # 2) Asegurar salidas
+       
         if hasattr(self.cfg, "ensure_output_dirs"):
             self.cfg.ensure_output_dirs()
 
-        # 3) Dump de defecto
+        
         if defect is not None and str(defect).strip():
             self.defect_path = Path(defect).expanduser().resolve()
         else:
@@ -52,14 +52,14 @@ class ClusterProcessor:
         if not self.defect_path.exists():
             raise FileNotFoundError(f"No existe el dump de defecto: {self.defect_path}")
 
-        # 4) Parámetros desde config
+        
         self.smoothing_level = int(getattr(self.cfg.preprocessing, "smoothing_level_inference", 0))
         self.radius_probe = float(getattr(self.cfg.graph, "neighbor_radius", 1.0)) or 1.0
         cutoff_graph = float(getattr(self.cfg.graph, "cutoff", 0.0))
-        cutoff_compat = float(getattr(self.cfg.clustering, "cutoff", 0.0) or 0.0)  # compat JSON viejo
+        cutoff_compat = float(getattr(self.cfg.clustering, "cutoff", 0.0) or 0.0)  
         self.cutoff_radius = max(cutoff_graph, cutoff_compat, 3.0)
 
-        # 5) Salidas
+        
         self.outputs_root = Path(self.cfg.paths.outputs_root).expanduser().resolve()
         self.outputs_dump = self.outputs_root / "dump"
         self.outputs_json = self.outputs_root / "json"
@@ -70,7 +70,7 @@ class ClusterProcessor:
         """Ejecuta el pipeline y exporta resultados. Devuelve el número de clusters detectados."""
         pipeline = import_file(str(self.defect_path))
 
-        # 1) superficie + invertir + borrar
+        
         pipeline.modifiers.append(
             ConstructSurfaceModifier(
                 radius=self.radius_probe,
@@ -82,7 +82,7 @@ class ClusterProcessor:
         pipeline.modifiers.append(InvertSelectionModifier())
         pipeline.modifiers.append(DeleteSelectedModifier())
 
-        # 2) clustering
+        
         pipeline.modifiers.append(
             ClusterAnalysisModifier(
                 cutoff=self.cutoff_radius,
@@ -94,11 +94,11 @@ class ClusterProcessor:
         data = pipeline.compute()
         num_clusters = int(data.attributes.get("ClusterAnalysis.cluster_count", 0))
 
-        # Guardar conteo
+        
         with (self.outputs_json / "clusters.json").open("w", encoding="utf-8") as f:
             json.dump({"num_clusters": num_clusters}, f, indent=4)
 
-        # 3) export global
+       
         key_areas_dump_path = self.outputs_dump / "key_areas.dump"
         try:
             export_file(
@@ -118,7 +118,7 @@ class ClusterProcessor:
         except Exception as e:
             print(f"[WARN] No se pudo exportar {key_areas_dump_path.name}: {e}")
 
-        # 4) export por cluster
+       
         for i in range(1, num_clusters + 1):
             pipeline_2 = import_file(str(key_areas_dump_path))
             pipeline_2.modifiers.append(
